pypika package
==============

.. toctree::

   pypika.analytics
   pypika.dialects
   pypika.enums
   pypika.functions
   pypika.pseudocolumns
   pypika.queries
   pypika.terms
   pypika.utils

Module contents
---------------

.. automodule:: pypika
    :members:
    :undoc-members:
    :show-inheritance:
